from je_editor import traditional_chinese_word_dict


def update_traditional_chinese_word_dict():
    traditional_chinese_word_dict.update(
        {
            # application name
            "automation_editor_application_name": "Automation Editor",
            # Menubar
            "automation_menu_label": "自動化",
            "install_menu_label": "安裝",
            # Normal label
            "run_label": "運行",
            "help_label": "幫助",
            "project_label": "專案",
            # APITestka Menu
            "apitestka_menu_label": "APITestka",
            "apitestka_run_script_label": "運行 APITestka 腳本",
            "apitestka_run_script_with_send_label": "運行 APITestka 腳本並寄信",
            "apitestka_run_multi_script_label": "運行多個 APITestka 腳本",
            "apitestka_run_multi_script_with_send_label": "運行多個 APITestka 腳本並寄信",
            "apitestka_doc_label": "開啟 APITestka 文件",
            "apitestka_doc_tab_label": "APITestka 文件",
            "apitestka_github_label": "開啟 APITestka GitHub",
            "apitestka_github_tab_label": "APITestka GitHub",
            "apitestka_create_project_label": "建立 APITestka 專案",
            # Autocontrol Menu
            "autocontrol_menu_label": "Autocontrol",
            "autocontrol_run_script_label": "運行 Autocontrol 腳本",
            "autocontrol_run_script_with_send_label": "運行 Autocontrol 腳本並寄信",
            "autocontrol_run_multi_script_label": "運行 Multi Autocontrol 腳本",
            "autocontrol_run_multi_script_with_send_label": "運行 Multi Autocontrol 腳本 腳本並寄信",
            "autocontrol_doc_label": "開啟 Autocontrol 文件",
            "autocontrol_doc_tab_label": "Autocontrol 文件",
            "autocontrol_github_label": "開啟 Autocontrol GitHub",
            "autocontrol_github_tab_label": "Autocontrol GitHub",
            "autocontrol_create_project_label": "建立 Autocontrol 專案",
            "autocontrol_record_menu_label": "紀錄",
            "autocontrol_record_start_label": "紀錄 Start",
            "autocontrol_record_stop_label": "紀錄 Stop",
            # File Automation Menu
            "file_automation_menu_label": "FileAutomation",
            "file_automation_run_script_label": "運行 FileAutomation 腳本",
            "file_automation_run_script_with_send_label": "運行 FileAutomation 腳本並寄信",
            "file_automation_run_multi_script_label": "運行 Multi FileAutomation 腳本",
            "file_automation_run_multi_script_with_send_label": "運行 Multi FileAutomation 腳本 腳本並寄信",
            "file_automation_doc_label": "開啟 FileAutomation 文件",
            "file_automation_doc_tab_label": "FileAutomation 文件",
            "file_automation_github_label": "開啟 FileAutomation GitHub",
            "file_automation_github_tab_label": "FileAutomation GitHub",
            "file_automation_create_project_label": "建立 FileAutomation 專案",
            # Load Density Menu
            "load_density_menu_label": "LoadDensity",
            "load_density_run_script_label": "運行 LoadDensity 腳本",
            "load_density_run_script_with_send_label": "運行 LoadDensity 腳本並寄信",
            "load_density_run_multi_script_label": "運行 Multi LoadDensity 腳本",
            "load_density_run_multi_script_with_send_label": "運行 Multi LoadDensity 腳本 腳本並寄信",
            "load_density_doc_label": "開啟 LoadDensity 文件",
            "load_density_doc_tab_label": "LoadDensity 文件",
            "load_density_github_label": "開啟 LoadDensity GitHub",
            "load_density_github_tab_label": "LoadDensity GitHub",
            "load_density_create_project_label": "建立 LoadDensity 專案",
            # Mail Thunder Menu
            "mail_thunder_menu_label": "MailThunder",
            "mail_thunder_run_script_label": "運行 MailThunder 腳本",
            "mail_thunder_doc_label": "開啟 MailThunder 文件",
            "mail_thunder_doc_tab_label": "MailThunder 文件",
            "mail_thunder_github_label": "開啟 MailThunder GitHub",
            "mail_thunder_github_tab_label": "MailThunder GitHub",
            "mail_thunder_create_project_label": "建立 MailThunder 專案",
            # Webrunner Menu
            "web_runner_menu_label": "WebRunner",
            "web_runner_run_script_label": "運行 WebRunner 腳本",
            "web_runner_run_script_with_send_label": "運行 WebRunner 腳本並寄信",
            "web_runner_run_multi_script_label": "運行 Multi WebRunner 腳本",
            "web_runner_run_multi_script_with_send_label": "運行 Multi WebRunner 腳本 腳本並寄信",
            "web_runner_doc_label": "開啟 WebRunner 文件",
            "web_runner_doc_tab_label": "WebRunner 文件",
            "web_runner_github_label": "開啟 WebRunner GitHub",
            "web_runner_github_tab_label": "WebRunner GitHub",
            "web_runner_create_project_label": "建立 WebRunner 專案",
            # Install Menu
            "install_menu_autocontrol": "安裝 AutoControl",
            "install_menu_apitestka": "安裝 APITestka",
            "install_menu_loaddensity": "安裝 LoadDensity",
            "install_menu_webrunner": "安裝 WebRunner",
            "install_menu_automation_file": "安裝 Automation File",
            "install_menu_mail_thunder": "安裝 MailThunder",
            "install_menu_tools_install_menu_label": "工具",
            "install_menu_tools_install_build_tools": "安裝 Build Tools",
            # Tools Menu
            "tools_menu_re_edge_gpt_label": "ReEdgeGPT",
            "tools_menu_re_edge_gpt_doc_label": "開啟 ReEdgeGPT 文件",
            "tools_menu_re_edge_gpt_doc_tab_label": "ReEdgeGPT 文件",
            "tools_menu_re_edge_gpt_github_label": "開啟 ReEdgeGPT GitHub",
            "tools_menu_re_edge_gpt_github_tab_label": "ReEdgeGPT GitHub",
        }
    )
