from je_editor import english_word_dict


def update_english_word_dict():
    english_word_dict.update(
        {
            # application name
            "automation_editor_application_name": "Automation Editor",
            # Menubar
            "automation_menu_label": "Automation",
            "install_menu_label": "Install",
            # Normal label
            "run_label": "Run",
            "help_label": "HELP",
            "project_label": "Project",
            # APITestka Menu
            "apitestka_menu_label": "APITestka",
            "apitestka_run_script_label": "Run APITestka Script",
            "apitestka_run_script_with_send_label": "Run APITestka With Send",
            "apitestka_run_multi_script_label": "Run Multi APITestka Script",
            "apitestka_run_multi_script_with_send_label": "Run Multi APITestka Script With Send",
            "apitestka_doc_label": "Open APITestka Doc",
            "apitestka_doc_tab_label": "APITestka Doc",
            "apitestka_github_label": "Open APITestka GitHub",
            "apitestka_github_tab_label": "APITestka GitHub",
            "apitestka_create_project_label": "Create APITestka Project",
            # Autocontrol Menu
            "autocontrol_menu_label": "Autocontrol",
            "autocontrol_run_script_label": "Run Autocontrol Script",
            "autocontrol_run_script_with_send_label": "Run Autocontrol With Send",
            "autocontrol_run_multi_script_label": "Run Multi Autocontrol Script",
            "autocontrol_run_multi_script_with_send_label": "Run Multi Autocontrol Script With Send",
            "autocontrol_doc_label": "Open Autocontrol Doc",
            "autocontrol_doc_tab_label": "Autocontrol Doc",
            "autocontrol_github_label": "Open Autocontrol GitHub",
            "autocontrol_github_tab_label": "Autocontrol GitHub",
            "autocontrol_create_project_label": "Create Autocontrol Project",
            "autocontrol_record_menu_label": "Record",
            "autocontrol_record_start_label": "Record Start",
            "autocontrol_record_stop_label": "Record Stop",
            # File Automation Menu
            "file_automation_menu_label": "FileAutomation",
            "file_automation_run_script_label": "Run FileAutomation Script",
            "file_automation_run_script_with_send_label": "Run FileAutomation With Send",
            "file_automation_run_multi_script_label": "Run Multi FileAutomation Script",
            "file_automation_run_multi_script_with_send_label": "Run Multi FileAutomation Script With Send",
            "file_automation_doc_label": "Open FileAutomation Doc",
            "file_automation_doc_tab_label": "FileAutomation Doc",
            "file_automation_github_label": "Open FileAutomation GitHub",
            "file_automation_github_tab_label": "FileAutomation GitHub",
            "file_automation_create_project_label": "Create FileAutomation Project",
            # Load Density Menu
            "load_density_menu_label": "LoadDensity",
            "load_density_run_script_label": "Run LoadDensity Script",
            "load_density_run_script_with_send_label": "Run LoadDensity With Send",
            "load_density_run_multi_script_label": "Run Multi LoadDensity Script",
            "load_density_run_multi_script_with_send_label": "Run Multi LoadDensity Script With Send",
            "load_density_doc_label": "Open LoadDensity Doc",
            "load_density_doc_tab_label": "LoadDensity Doc",
            "load_density_github_label": "Open LoadDensity GitHub",
            "load_density_github_tab_label": "LoadDensity GitHub",
            "load_density_create_project_label": "Create LoadDensity Project",
            # Mail Thunder Menu
            "mail_thunder_menu_label": "MailThunder",
            "mail_thunder_run_script_label": "Run MailThunder Script",
            "mail_thunder_doc_label": "Open MailThunder Doc",
            "mail_thunder_doc_tab_label": "MailThunder Doc",
            "mail_thunder_github_label": "Open MailThunder GitHub",
            "mail_thunder_github_tab_label": "MailThunder GitHub",
            "mail_thunder_create_project_label": "Create MailThunder Project",
            # Webrunner Menu
            "web_runner_menu_label": "WebRunner",
            "web_runner_run_script_label": "Run WebRunner Script",
            "web_runner_run_script_with_send_label": "Run WebRunner With Send",
            "web_runner_run_multi_script_label": "Run Multi WebRunner Script",
            "web_runner_run_multi_script_with_send_label": "Run Multi WebRunner Script With Send",
            "web_runner_doc_label": "Open WebRunner Doc",
            "web_runner_doc_tab_label": "WebRunner Doc",
            "web_runner_github_label": "Open WebRunner GitHub",
            "web_runner_github_tab_label": "WebRunner GitHub",
            "web_runner_create_project_label": "Create WebRunner Project",
            # Install Menu
            "install_menu_autocontrol": "Install AutoControl",
            "install_menu_apitestka": "Install APITestka",
            "install_menu_loaddensity": "Install LoadDensity",
            "install_menu_webrunner": "Install WebRunner",
            "install_menu_automation_file": "Install Automation File",
            "install_menu_mail_thunder": "Install MailThunder",
            "install_menu_tools_install_menu_label": "Tools",
            "install_menu_tools_install_build_tools": "Install Build Tools",
            # Tools Menu
            "tools_menu_re_edge_gpt_label": "ReEdgeGPT",
            "tools_menu_re_edge_gpt_doc_label": "Open ReEdgeGPT Doc",
            "tools_menu_re_edge_gpt_doc_tab_label": "ReEdgeGPT Doc",
            "tools_menu_re_edge_gpt_github_label": "Open ReEdgeGPT GitHub",
            "tools_menu_re_edge_gpt_github_tab_label": "ReEdgeGPT GitHub",
        }
    )
